@@ -48,11 +48,12 @@ return array (
 		'email' => array (
 			'url' => 'customer_email.php',
 			'label' => $lng['menue']['email']['email'],
+			'show_element' => ( !Settings::IsInList('panel.customer_hide_options','email') ),
 			'elements' => array (
 				array (
 					'url' => 'customer_email.php?page=emails',
 					'label' => $lng['menue']['email']['emails'],
-					'required_resources' => 'emails',
+					'required_resources' => 'emails'
 				),
 				array (
 					'url' => 'customer_email.php?page=emails&action=add',
@@ -71,6 +72,7 @@ return array (
 		'mysql' => array (
 			'url' => 'customer_mysql.php',
 			'label' => $lng['menue']['mysql']['mysql'],
+			'show_element' => ( !Settings::IsInList('panel.customer_hide_options','mysql') ),
 			'elements' => array (
 				array (
 					'url' => 'customer_mysql.php?page=mysqls',
@@ -89,6 +91,7 @@ return array (
 		'domains' => array (
 			'url' => 'customer_domains.php',
 			'label' => $lng['menue']['domains']['domains'],
+			'show_element' => ( !Settings::IsInList('panel.customer_hide_options','domains') ),
 			'elements' => array (
 				array (
 					'url' => 'customer_domains.php?page=domains',
@@ -99,6 +102,7 @@ return array (
 		'ftp' => array (
 			'url' => 'customer_ftp.php',
 			'label' => $lng['menue']['ftp']['ftp'],
+			'show_element' => ( !Settings::IsInList('panel.customer_hide_options','ftp') ),
 			'elements' => array (
 				array (
 					'url' => 'customer_ftp.php?page=accounts',
@@ -115,25 +119,34 @@ return array (
 		'extras' => array (
 			'url' => 'customer_extras.php',
 			'label' => $lng['menue']['extras']['extras'],
+			'show_element' => ( !Settings::IsInList('panel.customer_hide_options','extras') ),
 			'elements' => array (
 				array (
 					'url' => 'customer_extras.php?page=htpasswds',
 					'label' => $lng['menue']['extras']['directoryprotection'],
+					'show_element' => ( !Settings::IsInList('panel.customer_hide_options','extras.directoryprotection') ),
 				),
 				array (
 					'url' => 'customer_extras.php?page=htaccess',
 					'label' => $lng['menue']['extras']['pathoptions'],
+					'show_element' => ( !Settings::IsInList('panel.customer_hide_options','extras.pathoptions') ),
+				),
+				array (
+					'url' => 'customer_logger.php?page=log',
+					'label' => $lng['menue']['logger']['logger'],
+					'show_element' => ( Settings::Get('logger.enabled') == true ) && ( !Settings::IsInList('panel.customer_hide_options','extras.logger') ),
+				),
+				array (
+					'url' => 'customer_extras.php?page=backup',
+					'label' => $lng['menue']['extras']['backup'],
+					'show_element' => ( Settings::Get('system.backupenabled') == true )  && ( !Settings::IsInList('panel.customer_hide_options','extras.backup') ),
 				),
-			    array (
-			        'url' => 'customer_logger.php?page=log',
-			        'label' => $lng['menue']['logger']['logger'],
-			        'show_element' => ( Settings::Get('logger.enabled') == true )
-			    ),
 			),
 		),
 		'traffic' => array (
 			'url' => 'customer_traffic.php',
 			'label' => $lng['menue']['traffic']['traffic'],
+			'show_element' => ( !Settings::IsInList('panel.customer_hide_options','traffic') ),
 			'elements' => array (
 				array (
 					'url' => 'customer_traffic.php?page=current',
